# COCI

<strong>C</strong>ollective <strong>O</strong>bservation on <strong>C</strong>ausal <strong>I</strong>nferences

Coci makes it easy to observe the changes in predictions from machine learning models based on the alterations of feature values.

## Why Coci?

Machine learning has always been understood as a black box algorithm, which makes the decision makers hesitant to trust the predictions from this approach.

<a href="https://github.com/slundberg/shap">Shap</a> and <a href="https://github.com/marcotcr/lime">Lime</a> has unveiled a lot of mysteries around the effects of the presence of each feature on outcomes. 

Coci takes it a step further, and reveals the effects on outcomes when changing feature values. 